@@ -7,7 +7,7 @@ use Carp;
 
 use base 'DynaLoader';
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 bootstrap RRD::Tweak;
 
 # Internal object structure:
@@ -1252,7 +1252,7 @@ sub modify_rra {
             }
 
             unshift(@{$rra_data}, @{$prepend_rra_data});
-            
+
             # try to derive the data rows where possible
             $self->_populate_rra($mod_rra_index);
         }
@@ -1471,6 +1471,11 @@ sub _populate_rra
         return;
     }
 
+    if( $hw_rra_name{$cf} ) {
+        # this is a Holt-Winters array, and we don't know how to populate it
+        return;
+    }
+
     my %rraidx_per_steps;
     for( my $rra=0; $rra < $n_rra; $rra++) {
         if( $rra != $pop_rra_index ) {
@@ -1600,6 +1605,8 @@ Stanislav Sinyagin, C<< <ssinyagin at k-open.com> >>
 
 =head1 ACKNOWLEDGEMENTS
 
+This development has been sponsored by Nexellent AG and UPC Cablecom AG,
+Switzerland.
 
 =head1 LICENSE AND COPYRIGHT
 
